==> rc-ui-lib-0.1.41.tgz: package/es/circle/Circle.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext, useEffect, useMemo, useState } from 'react';
import classnames from 'classnames';
import { isObject, getSizeStyle } from '../utils';
import { cancelRaf, raf } from '../utils/raf';
import useMergedState from '../hooks/use-merged-state';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var uid = 0;

function format(rate) {
  return Math.min(Math.max(+rate, 0), 100);
}

function getPath(clockwise, viewBoxSize) {
  var sweepFlag = clockwise ? 1 : 0;
  return "M ".concat(viewBoxSize / 2, " ").concat(viewBoxSize / 2, " m 0, -500 a 500, 500 0 1, ").concat(sweepFlag, " 0, 1000 a 500, 500 0 1, ").concat(sweepFlag, " 0, -1000");
}

var ROTATE_ANGLE_MAP = {
  top: 0,
  right: 90,
  bottom: 180,
  left: 270
};

var Circle = function Circle(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('circle', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0]; // eslint-disable-next-line no-plusplus


  var id = "van-circle-".concat(uid++);

  var _useState = useState(function () {
    return props.defaultRate || 0;
  }),
      _useState2 = _slicedToArray(_useState, 2),
      currentRate = _useState2[0],
      setCurrentRate = _useState2[1];

  var _useMergedState = useMergedState({
    defaultValue: props.defaultRate,
    value: props.rate
  }),
      _useMergedState2 = _slicedToArray(_useMergedState, 1),
      current = _useMergedState2[0];

  var viewBoxSize = useMemo(function () {
    return +props.strokeWidth + 1000;
  }, [props.strokeWidth]);
  var path = useMemo(function () {
    return getPath(props.clockwise, viewBoxSize);
  }, [props.clockwise, viewBoxSize]);
  var svgStyle = useMemo(function () {
    var angleValue = ROTATE_ANGLE_MAP[props.startPosition];

    if (angleValue) {
      return {
        transform: "rotate(".concat(angleValue, "deg)")
      };
    }

    return undefined;
  }, [props.startPosition]);
  useEffect(function () {
    var rafId;
    var startTime = Date.now();
    var startRate = currentRate;
    var endRate = format(current);
    var duration = Math.abs((startRate - endRate) * 1000 / +props.speed);

    var animate = function animate() {
      var now = Date.now();
      var progress = Math.min((now - startTime) / duration, 1);
      var rate = progress * (endRate - startRate) + startRate;
      var crate = format(parseFloat(rate.toFixed(1)));
      setCurrentRate(crate);

      if (endRate > startRate ? rate < endRate : rate > endRate) {
        rafId = raf(animate);
      } else {
        var _props$onChange;

        (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, crate);
      }
    };

    if (props.speed) {
      if (rafId) {
        cancelRaf(rafId);
      }

      rafId = raf(animate);
    } else {
      setCurrentRate(endRate);
    }
  }, [current]);

  var renderHover = function renderHover() {
    var PERIMETER = 3140;
    var strokeWidth = props.strokeWidth;
    var offset = PERIMETER * currentRate / 100;
    var color = isObject(props.color) ? "url(#".concat(id, ")") : props.color;
    var style = {
      stroke: color,
      strokeWidth: "".concat(+strokeWidth + 1, "px"),
      strokeLinecap: props.strokeLinecap,
      strokeDasharray: "".concat(offset, "px ").concat(PERIMETER, "px")
    };
    return /*#__PURE__*/React.createElement("path", {
      d: path,
      style: style,
      className: classnames(bem('hover')),
      stroke: color
    });
  };

  var renderLayer = function renderLayer() {
    var style = {
      fill: props.fill,
      stroke: props.layerColor,
      strokeWidth: "".concat(props.strokeWidth, "px")
    };
    return /*#__PURE__*/React.createElement("path", {
      className: classnames(bem('layer')),
      style: style,
      d: path
    });
  };

  var renderGradient = function renderGradient() {
    var color = props.color;

    if (!isObject(color)) {
      return null;
    }

    var Stops = Object.keys(color).sort(function (a, b) {
      return parseFloat(a) - parseFloat(b);
    }) // eslint-disable-next-line react/no-array-index-key
    .map(function (key, index) {
      return /*#__PURE__*/React.createElement("stop", {
        key: index,
        offset: key,
        stopColor: color[key]
      });
    });
    return /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("linearGradient", {
      id: id,
      x1: "100%",
      y1: "0%",
      x2: "0%",
      y2: "0%"
    }, Stops));
  };

  var renderText = function renderText() {
    if (props.text) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('text'))
      }, props.text);
    }

    return props.children;
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classnames(bem(), props.className),
    style: _objectSpread(_objectSpread({}, props.style), getSizeStyle(props.size))
  }, /*#__PURE__*/React.createElement("svg", {
    viewBox: "0 0 ".concat(viewBoxSize, " ").concat(viewBoxSize),
    style: svgStyle
  }, renderGradient(), renderLayer(), renderHover()), renderText());
};

Circle.defaultProps = {
  clockwise: true,
  speed: 100,
  fill: 'none',
  strokeWidth: 40,
  startPosition: 'top'
};
export default Circle;

==> rc-ui-lib-0.1.51.tgz: package/es/circle/Circle.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext, useEffect, useMemo, useState } from 'react';
import classnames from 'classnames';
import { isObject, getSizeStyle } from '../utils';
import { cancelRaf, raf } from '../utils/raf';
import useMergedState from '../hooks/use-merged-state';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var uid = 0;

function format(rate) {
  return Math.min(Math.max(+rate, 0), 100);
}

function getPath(clockwise, viewBoxSize) {
  var sweepFlag = clockwise ? 1 : 0;
  return "M ".concat(viewBoxSize / 2, " ").concat(viewBoxSize / 2, " m 0, -500 a 500, 500 0 1, ").concat(sweepFlag, " 0, 1000 a 500, 500 0 1, ").concat(sweepFlag, " 0, -1000");
}

var ROTATE_ANGLE_MAP = {
  top: 0,
  right: 90,
  bottom: 180,
  left: 270
};

var Circle = function Circle(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('circle', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0]; // eslint-disable-next-line no-plusplus


  var id = "rc-circle-".concat(uid++);

  var _useState = useState(function () {
    return props.defaultRate || 0;
  }),
      _useState2 = _slicedToArray(_useState, 2),
      currentRate = _useState2[0],
      setCurrentRate = _useState2[1];

  var _useMergedState = useMergedState({
    defaultValue: props.defaultRate,
    value: props.rate
  }),
      _useMergedState2 = _slicedToArray(_useMergedState, 1),
      current = _useMergedState2[0];

  var viewBoxSize = useMemo(function () {
    return +props.strokeWidth + 1000;
  }, [props.strokeWidth]);
  var path = useMemo(function () {
    return getPath(props.clockwise, viewBoxSize);
  }, [props.clockwise, viewBoxSize]);
  var svgStyle = useMemo(function () {
    var angleValue = ROTATE_ANGLE_MAP[props.startPosition];

    if (angleValue) {
      return {
        transform: "rotate(".concat(angleValue, "deg)")
      };
    }

    return undefined;
  }, [props.startPosition]);
  useEffect(function () {
    var rafId;
    var startTime = Date.now();
    var startRate = currentRate;
    var endRate = format(current);
    var duration = Math.abs((startRate - endRate) * 1000 / +props.speed);

    var animate = function animate() {
      var now = Date.now();
      var progress = Math.min((now - startTime) / duration, 1);
      var rate = progress * (endRate - startRate) + startRate;
      var crate = format(parseFloat(rate.toFixed(1)));
      setCurrentRate(crate);

      if (endRate > startRate ? rate < endRate : rate > endRate) {
        rafId = raf(animate);
      } else {
        var _props$onChange;

        (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, crate);
      }
    };

    if (props.speed) {
      if (rafId) {
        cancelRaf(rafId);
      }

      rafId = raf(animate);
    } else {
      setCurrentRate(endRate);
    }
  }, [current]);

  var renderHover = function renderHover() {
    var PERIMETER = 3140;
    var strokeWidth = props.strokeWidth;
    var offset = PERIMETER * currentRate / 100;
    var color = isObject(props.color) ? "url(#".concat(id, ")") : props.color;
    var style = {
      stroke: color,
      strokeWidth: "".concat(+strokeWidth + 1, "px"),
      strokeLinecap: props.strokeLinecap,
      strokeDasharray: "".concat(offset, "px ").concat(PERIMETER, "px")
    };
    return /*#__PURE__*/React.createElement("path", {
      d: path,
      style: style,
      className: classnames(bem('hover')),
      stroke: color
    });
  };

  var renderLayer = function renderLayer() {
    var style = {
      fill: props.fill,
      stroke: props.layerColor,
      strokeWidth: "".concat(props.strokeWidth, "px")
    };
    return /*#__PURE__*/React.createElement("path", {
      className: classnames(bem('layer')),
      style: style,
      d: path
    });
  };

  var renderGradient = function renderGradient() {
    var color = props.color;

    if (!isObject(color)) {
      return null;
    }

    var Stops = Object.keys(color).sort(function (a, b) {
      return parseFloat(a) - parseFloat(b);
    }) // eslint-disable-next-line react/no-array-index-key
    .map(function (key, index) {
      return /*#__PURE__*/React.createElement("stop", {
        key: index,
        offset: key,
        stopColor: color[key]
      });
    });
    return /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("linearGradient", {
      className: "linearGradient",
      id: id,
      x1: "100%",
      y1: "0%",
      x2: "0%",
      y2: "0%"
    }, Stops));
  };

  var renderText = function renderText() {
    if (props.text) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('text'))
      }, props.text);
    }

    return props.children;
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classnames(bem(), props.className),
    style: _objectSpread(_objectSpread({}, props.style), getSizeStyle(props.size))
  }, /*#__PURE__*/React.createElement("svg", {
    viewBox: "0 0 ".concat(viewBoxSize, " ").concat(viewBoxSize),
    style: svgStyle
  }, renderGradient(), renderLayer(), renderHover()), renderText());
};

Circle.defaultProps = {
  clockwise: true,
  speed: 100,
  fill: 'none',
  strokeWidth: 40,
  startPosition: 'top'
};
export default Circle;
